.. _mrs_imatch_step:

=====================
MIRI MRS Sky Matching
=====================

.. moduleauthor:: Mihai Cara <help@stsci.edu>

.. toctree::
   :maxdepth: 2

   description.rst
   mrs_imatch_step.rst

.. automodapi:: jwst.mrs_imatch
